pub enum Expr {
Show 21 variants
ArrayExpr(ArrayExpr),
ArrayLiteral(ArrayLiteral),
BinExpr(BinExpr),
BlockExpr(BlockExpr),
BoxExpr(BoxExpr),
CallExpr(CallExpr),
CastExpression(CastExpression),
GateCallExpr(GateCallExpr),
GPhaseCallExpr(GPhaseCallExpr),
HardwareQubit(HardwareQubit),
Identifier(Identifier),
IndexExpr(IndexExpr),
IndexedIdentifier(IndexedIdentifier),
Literal(Literal),
TimingLiteral(TimingLiteral),
MeasureExpression(MeasureExpression),
ModifiedGateCallExpr(ModifiedGateCallExpr),
ParenExpr(ParenExpr),
PrefixExpr(PrefixExpr),
RangeExpr(RangeExpr),
ReturnExpr(ReturnExpr),
}Variants
ArrayExpr(ArrayExpr)
ArrayLiteral(ArrayLiteral)
BinExpr(BinExpr)
BlockExpr(BlockExpr)
BoxExpr(BoxExpr)
CallExpr(CallExpr)
CastExpression(CastExpression)
GateCallExpr(GateCallExpr)
GPhaseCallExpr(GPhaseCallExpr)
HardwareQubit(HardwareQubit)
Identifier(Identifier)
IndexExpr(IndexExpr)
IndexedIdentifier(IndexedIdentifier)
Literal(Literal)
TimingLiteral(TimingLiteral)
MeasureExpression(MeasureExpression)
ModifiedGateCallExpr(ModifiedGateCallExpr)
ParenExpr(ParenExpr)
PrefixExpr(PrefixExpr)
RangeExpr(RangeExpr)
ReturnExpr(ReturnExpr)
Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn needs_parens_in(&self, parent: SyntaxNode) -> bool
pub fn needs_parens_in(&self, parent: SyntaxNode) -> bool
Returns true if self would need to be wrapped in parentheses given that its parent is parent.